# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .property_update_params import PropertyUpdateParams as PropertyUpdateParams
